Struct DnsSeed

pub struct DnsSeed {
    pub network: Network,
    pub seed: &'static str,
    pub filters: ServiceFlags,
}
A dns seed is a authoritative DNS server that returns the IP addresses of nodes that are likely to be accepting incoming connections. This is our preferred way of finding new peers on the first startup, as peers returned by seeds are likely to be online and accepting connections. We may use this as a fallback if we don’t have any peers to connect in subsequent startups.

Some seeds allow filtering by service flags, so we may use this to find peers that are likely to be running Utreexo, for example.

Fields

network: Network

The network this peer supports (e.g, mainnet, testnet, etc)

seed: &'static str

The domain name of the seed

filters: ServiceFlags

Useful filters we can use to find relevant peers

Implementations

Source

impl DnsSeed

This functionality is used to create a new DNS seed with possible filters.

pub fn new(network: Network, seed: &'static str, filters: ServiceFlags) -> Self

Create a new DNS seed